from typing import Optional

from pydantic import EmailStr, Field

from app.schemas.base import BaseSchema, BaseSchemaIDTimestamps


class UserBase(BaseSchema):
    """Base schema for user."""
    email: EmailStr
    full_name: Optional[str] = None
    company_name: Optional[str] = None
    address: Optional[str] = None
    phone_number: Optional[str] = None
    is_active: bool = True
    is_superuser: bool = False


class UserCreate(UserBase):
    """Schema for creating a user."""
    password: str = Field(..., min_length=8, max_length=100)


class UserUpdate(BaseSchema):
    """Schema for updating a user."""
    email: Optional[EmailStr] = None
    full_name: Optional[str] = None
    company_name: Optional[str] = None
    address: Optional[str] = None
    phone_number: Optional[str] = None
    password: Optional[str] = Field(None, min_length=8, max_length=100)
    is_active: Optional[bool] = None
    is_superuser: Optional[bool] = None


class UserInDBBase(UserBase, BaseSchemaIDTimestamps):
    """Base schema for user in database."""
    pass


class User(UserInDBBase):
    """Schema for user without sensitive data."""
    pass


class UserInDB(UserInDBBase):
    """Schema for user in database with hashed password."""
    hashed_password: str